@@ -13,7 +13,8 @@ const data_feature_type_t DATA_FEATURE_TYPE_ARRAY [DATA_FEATURE_TYPE_COUNT]
         DATA_FEATURE_TYPE_IN_PORT_PIN,
         DATA_FEATURE_TYPE_OUT_PORT_PIN,
         DATA_FEATURE_TYPE_ENTRY,
-        DATA_FEATURE_TYPE_EXIT
+        DATA_FEATURE_TYPE_EXIT,
+        DATA_FEATURE_TYPE_TAGGED_VALUE
     };
 
 
