@@ -3,7 +3,8 @@
 #include "data_database_listener_test.h"
 #include "storage/data_database_listener.h"
 #include "storage/data_database.h"
-#include "test_assert.h"
+#include "test_expect.h"
+#include "test_environment_assert.h"
 
 static void set_up(void);
 static void tear_down(void);
@@ -48,30 +49,30 @@ static void test_database_listener_register_and_notify(void)
     data_database_init ( &db );
 
     d_err = data_database_add_db_listener( &db, &my_listener1 );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
 
     d_err = data_database_add_db_listener( &db, &my_listener2 );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
 
     d_err = data_database_add_db_listener( &db, &my_listener1 );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_INVALID_REQUEST, d_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_INVALID_REQUEST, d_err );
 
     d_err = data_database_private_notify_db_listeners( &db, DATA_DATABASE_LISTENER_SIGNAL_PREPARE_CLOSE );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
-    TEST_ASSERT_EQUAL_INT( 2, callback_counter );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
+    TEST_EXPECT_EQUAL_INT( 2, callback_counter );
 
     d_err = data_database_remove_db_listener( &db, &my_listener1 );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
 
     d_err = data_database_remove_db_listener( &db, &my_listener2 );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
 
     d_err = data_database_remove_db_listener( &db, &my_listener1 );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_INVALID_REQUEST, d_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_INVALID_REQUEST, d_err );
 
     d_err = data_database_private_notify_db_listeners( &db, DATA_DATABASE_LISTENER_SIGNAL_PREPARE_CLOSE );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
-    TEST_ASSERT_EQUAL_INT( 2, callback_counter );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
+    TEST_EXPECT_EQUAL_INT( 2, callback_counter );
 
     data_database_destroy ( &db );
     data_database_listener_destroy ( &my_listener2 );
@@ -90,21 +91,21 @@ static void test_database_listener_registration_full(void)
     {
         data_database_listener_init( &my_listener[index], &callback_counter, (void (*)(void*,data_database_listener_signal_t)) &callback_notification );
         d_err = data_database_add_db_listener( &db, &my_listener[index] );
-        TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
     }
     data_database_listener_init( &my_listener[DATA_DATABASE_MAX_LISTENERS], &callback_counter, (void (*)(void*,data_database_listener_signal_t)) &callback_notification );
     d_err = data_database_add_db_listener( &db, &my_listener[DATA_DATABASE_MAX_LISTENERS] );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_ARRAY_BUFFER_EXCEEDED, d_err );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_ARRAY_BUFFER_EXCEEDED, d_err );
 
     d_err = data_database_private_notify_db_listeners( &db, DATA_DATABASE_LISTENER_SIGNAL_PREPARE_CLOSE );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
-    TEST_ASSERT_EQUAL_INT( DATA_DATABASE_MAX_LISTENERS, callback_counter );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
+    TEST_EXPECT_EQUAL_INT( DATA_DATABASE_MAX_LISTENERS, callback_counter );
 
     data_database_private_clear_db_listener_list( &db );
 
     d_err = data_database_private_notify_db_listeners( &db, DATA_DATABASE_LISTENER_SIGNAL_PREPARE_CLOSE );
-    TEST_ASSERT_EQUAL_INT( U8_ERROR_NONE, d_err );
-    TEST_ASSERT_EQUAL_INT( DATA_DATABASE_MAX_LISTENERS, callback_counter );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, d_err );
+    TEST_EXPECT_EQUAL_INT( DATA_DATABASE_MAX_LISTENERS, callback_counter );
 
     for ( int index = 0; index < (DATA_DATABASE_MAX_LISTENERS+1); index ++ )
     {
@@ -115,7 +116,7 @@ static void test_database_listener_registration_full(void)
 
 
 /*
- * Copyright 2016-2022 Andreas Warnke
+ * Copyright 2016-2023 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
